.. _recipe_asr.pdos:

asr.pdos
========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.pdos`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.pdos.calculate`
  - :py:func:`asr.pdos.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.pdos

or as a python module

.. code-block:: console

   $ python -m asr.pdos

Detailed description
--------------------
Projected density of states.

Steps
-----


asr.pdos@calculate
^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.pdos.calculate
   

asr.pdos
^^^^^^^^
.. autofunction:: asr.pdos.main
   